import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  format
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const title = 'London Monthly Air Quality: Ozone vs. NO2';
  //const xValue = d => d['Roadside_PM2.5'];
  const xValue = d => d.Roadside_Ozone;
  const xAxisLabel = 'Ozone (ug/m3)';
  
  const yValue = d => d.Roadside_NitrogenDioxide;
  const circleRadius = 10;
  const yAxisLabel = 'Nitrogen Dioxide (ug/m3)';
  
  const margin = { top: 60, right: 40, bottom: 88, left: 150 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -75)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 75)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  g.selectAll('circle').data(data)
    .enter().append('circle')
      .attr('cy', d => yScale(yValue(d)))
      .attr('cx', d => xScale(xValue(d)))
      .attr('r', circleRadius);
  
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
};


csv('https://vizhub.com/KCachel/datasets/londonairqualityjan2010aug2018.csv')
  .then(data => {
    data.forEach(d => {
    d.Roadside_NitricOxide = +d.Roadside_NitricOxide;
    d.Roadside_NitrogenDioxide = +d.Roadside_NitrogenDioxide;
    d.Roadside_OxidesofNitrogen = +d.Roadside_OxidesofNitrogen;
    d.Roadside_Ozone = +d.Roadside_Ozone;
    d.Roadside_PM10 = +d.Roadside_PM10;
    d['Roadside_PM2.5'] = +d['Roadside_PM2.5']; 
    d.Roadside_SulphurDioxide = +d.Roadside_SulphurDioxide;
    d.Background_NitricOxide = +d.Background_NitricOxide;
    d.Background_NitrogenDioxide = +d.Background_NitrogenDioxide;
    d.Background_OxidesofNitrogen = +d.Background_OxidesofNitrogen;
    d.Background_Ozone = +d.Background_Ozone;
    d.Background_PM10 = +d.Background_PM10;
    d.Background_PM2.5 = +d['Background_PM2.5'];
    d.Background_SulphurDioxide = d.Background_SulphurDioxide;
      
    });
    render(data);
  });